<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="30"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="50"/>
        <source>About Scrobbler Plugin</source>
        <translation>關於 Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Scrobbler 插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>User name:</source>
        <translation>用戶名：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
</context>
</TS>
